@@ -3,7 +3,7 @@ import re
 from typing import Callable, TypeVar, get_type_hints, Type
 import xwire.transport
 from xwire.common import decorator_utils
-from xwire.rest._private.utils import get_cookies
+from xwire.rest._private.utils import get_cookies, get_headers
 from xwire.rest._private.proxy.decorators import resource
 
 
@@ -34,7 +34,7 @@ def get(path: str):
                 method_path = method_path.replace(path_param, str(arg))
 
             url = self.base_url + resource_metadata['resource_path'] + method_path
-            return _do_get(url, return_type, cookies=get_cookies(self))
+            return _do_get(url, return_type, cookies=get_cookies(self), headers=get_headers(self))
 
         return wrapper
     return decorator
