@@ -3,7 +3,7 @@ from typing import Dict, Type, TypeVar, get_type_hints, Callable
 import xwire.transport
 from xwire.common import decorator_utils
 from xwire.rest._private.proxy.decorators import resource
-from xwire.rest._private.utils import get_cookies
+from xwire.rest._private.utils import get_cookies, get_headers
 
 T = TypeVar('T')
 
@@ -26,7 +26,7 @@ def post(path: str):
             resource_metadata = decorator_utils.get_decorator_metadata(self, resource)
             url = self.base_url + resource_metadata['resource_path'] + path
             body = args[0]
-            return _do_post(url, xwire.transport.json.serialize(body), return_type, cookies=get_cookies(self))
+            return _do_post(url, xwire.transport.json.serialize(body), return_type, cookies=get_cookies(self), headers=get_headers(self))
 
         return wrapper
     return decorator
