@@ -8,7 +8,8 @@ def resource(resource_path: str):
     def decorator(cls: Type[T]) -> Type[T]:
         decorator_utils.set_decorator_metadata(cls, resource, {
             'resource_path': resource_path,
-            'cookies': None
+            'cookies': None,
+            'headers': None
         })
         return cls
     return decorator
